@@ -42,26 +42,24 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class WgetLayer(
-    aws_cdk.aws_lambda.LayerVersion,
+    _aws_cdk_aws_lambda_ceddda9d.LayerVersion,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-lambda-layer-wget.WgetLayer",
 ):
     '''An AWS Lambda layer that includes the wget.'''
 
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0931072c0e59e7f830f767242da2fc67a23ae3751a44b5c656c9194ca866e913)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -72,3 +70,10 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0931072c0e59e7f830f767242da2fc67a23ae3751a44b5c656c9194ca866e913(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
